# stocksymboltools

stocksymboltools is a Python library for retrieving stock symbols from CSV files.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install myLibrary.

```bash
pip install stocksymboltools==0.1
